autopew\.transform\.affine
--------------------------------
  .. automodule:: autopew.transform.affine
      :members:
      :undoc-members:

autopew\.transform\.vis
--------------------------------
  .. automodule:: autopew.transform.vis
      :members:
      :undoc-members:
